@@ -44,7 +44,7 @@ char* chum_get_selected_language(){
 	return selected_language;
 }
 
-void  chum_set_selected_language(gchar* language){
+void  chum_set_selected_language(const gchar* language){
 	selected_language=language;
 }
 
@@ -85,13 +85,16 @@ int chum_get_state_of_chum(){
 return state_of_chum;
 }
 
+#ifdef removed
 //THIS IS THE MAIN LOOP OF JAMMO!!!
 void chum_start_jammo_main_loop() {
     cem_add_to_log("starting main loop",LOG_DEBUG);
     gui_start_main_loop();
     cem_add_to_log("main loop is over",LOG_DEBUG);
 }
+#endif
 
+#ifdef removed
 void chum_start_chum(int argc, char** argv){
     int i;
     int port;
@@ -175,6 +178,7 @@ void chum_start_chum(int argc, char** argv){
     gui_go_screen(state_of_chum);
     chum_start_jammo_main_loop();
 }
+#endif
 
 void chum_test_instrument(int type) {
 	cem_add_to_log(g_strdup_printf("chum_test_instrument(%d)",type),LOG_DEBUG);
@@ -207,6 +211,7 @@ void chum_test_slider(int type) {
 
 }
 
+#ifdef removed
 void chum_go_back() {
     cem_add_to_log(g_strdup_printf("chum_go_back(). state_of_chum was %s...",name_of_states[state_of_chum]),LOG_DEBUG);
 
@@ -236,8 +241,9 @@ void chum_go_back() {
 
     gui_go_screen(state_of_chum);
 }
+#endif
 
-
+#ifdef removed
 void chum_go_next() {
     cem_add_to_log(g_strdup_printf("chum_go_next(). state_of_chum was %s...",name_of_states[state_of_chum]),LOG_DEBUG);
 
@@ -267,12 +273,15 @@ void chum_go_next() {
 
     gui_go_screen(state_of_chum);
 }
+#endif
 
+#ifdef removed
 void chum_go_screen(int screen_number){
     cem_add_to_log(g_strdup_printf("chum_go_screen(%s)",name_of_states[screen_number]),LOG_DEBUG);
     state_of_chum=screen_number;
     gui_go_screen(state_of_chum);
 }
+#endif
 
 //STUB
 void chum_change_to_game(int game_number){
@@ -322,11 +331,13 @@ void chum_change_theme(int theme_number){
     //gui_go_screen(state_of_chum);
 }
 
+#ifdef removed
 void chum_change_to_theme(int theme_number){
 chum_change_theme(theme_number);
     state_of_chum=SCREEN_COMPOSING;
     gui_go_screen(state_of_chum);
 }
+#endif
 
 char* chum_get_current_song(){
 cem_add_to_log(g_strdup_printf("get_current_song(). will return '%s'",current_song),LOG_DEBUG);
@@ -338,12 +349,6 @@ gchar *name =  (gchar *) g_list_nth_data(chum_get_all_songs(),i); //FIXME. now i
 return name;
 }
 
-//N900 has very limited /tmp space.
-#ifdef N900
-#define RECORDING_FILENAME "/home/user/.jammo/recording.wav"
-#else
-#define RECORDING_FILENAME "/tmp/recording.wav"
-#endif
 
 /*
 Always call this before gui_go_screen(SCREEN_PLAY_RECORDED);
@@ -419,7 +424,13 @@ void chum_change_to_song(const char *song_name){
   sample1 = jammo_sample_new_from_file(filename);
   jammo_editing_track_add_sample(backing_track, sample1, 0);
 
+  //Do not use pitch_detect on OFFICIAL_RELEASE (not robust enough)
+  #ifdef OFFICIAL_RELEASE
   recording_track = jammo_recording_track_new(RECORDING_FILENAME);
+  #else
+  recording_track = jammo_recording_track_new_with_pitch_detect(RECORDING_FILENAME);
+  #endif
+
   jammo_sequencer_add_track(sequencer, JAMMO_TRACK(recording_track));
 
   state_of_chum=SCREEN_SONG_RECORDING;
@@ -436,15 +447,10 @@ void chum_play_sequencer(){
 	
   //  chum_stop_sequencer();
     cem_add_to_log("chum_play_sequencer()",LOG_DEBUG);
-    gui_visualize_playing(state_of_chum);
+//    gui_visualize_playing(state_of_chum);
 	jammo_sequencer_play((JammoSequencer*)sequencer);
 }
 
-void chum_report_melodic_contour(float freq){
-gui_visualize_contour(freq);
-}
-
-
 void chum_get_duration_of_song(guint64 *value) {
 	*value = jammo_sequencer_get_duration(sequencer);
 }
@@ -494,6 +500,8 @@ return chum_add_new_sample_to_track(track, id, srcLocation, slot * GST_SECOND);
 }
 
 
+#ifdef removed_temp
+//THIS IS TEMPORARILY REMOVED. Because whole gui_clutter/*.c is removed.
 JammoSample* chum_add_new_sample_to_track_remote(int a, const gchar* id, guint64 startTime){
 cem_add_to_log(g_strdup_printf(" chum_add_new_sample_to_track_remote(%d,%s,%" GST_TIME_FORMAT ")",a, id,GST_TIME_ARGS (startTime)),LOG_DEBUG);
 gchar* sound=object_add_to_timeline_remote(id,startTime);
@@ -502,7 +510,11 @@ gchar* buffer0;
 buffer0 = g_strdup_printf("%s/themes/%s/%s",DATA_DIR,chum_get_theme_folder(chum_get_current_theme()), sound);
 return chum_add_new_sample_to_track(editing_track_partner,id,buffer0,startTime);
 }
-
+#else
+JammoSample* chum_add_new_sample_to_track_remote(int a, const gchar* id, guint64 startTime){
+return NULL;
+}
+#endif
 
 void chum_remove_sample_from_slot_remote(int a, int slot){
 	chum_remove_sample_from_slot(editing_track_partner, slot);
@@ -533,7 +545,7 @@ const gchar* chum_get_theme_folder(int index){
 }
 
 
-
+#ifdef removed
 static int chum_count_themes(){
     g_return_val_if_fail(THEMES_DIR,-1);
     GError* error = NULL;
@@ -554,6 +566,7 @@ static int chum_count_themes(){
    }
 return number_of_themes;
 }
+#endif
 
 void chum_get_all_slot_info(int track_number){
 cem_add_to_log(g_strdup_printf("chum_get_all_slot_info(%d)",track_number),LOG_DEBUG);
