@@ -27,6 +27,14 @@ This file is for clutter based gui and it handles config file reading
 #define THEMES_DIR DATA_DIR "/themes"
 #define SONGS_DIR DATA_DIR "/songs"
 
+//N900 has very limited /tmp space.
+#ifdef N900
+#define RECORDING_FILENAME "/home/user/.jammo/recording.wav"
+#else
+#define RECORDING_FILENAME "/tmp/recording.wav"
+#endif
+
+
 /* This is temporary location: move to jammo.h or similar. */
 ClutterActor* jammo_get_actor_by_id(const gchar* id);
 
@@ -63,7 +71,7 @@ void chum_change_to_song(const char* song_name);
 void chum_play_recorded_and_backing_track();
 
 char* chum_get_selected_language();
-void  chum_set_selected_language(gchar* language);
+void  chum_set_selected_language(const gchar* language);
 void chum_set_duetto(gboolean b);
 
 void chum_stop_sequencer();
