@@ -14,7 +14,12 @@
 #include <clutter/clutter.h>
 #include <stdlib.h> 
 
-#include "jammo-mentor.h"
+#include "chum.h" //e.g. DATA_DIR
+#include <fcntl.h> //we check some files
+#include "mentor.h"
+
+#include <pthread.h> 
+
 static const char* search_path = "/opt/jammo";
 
 /*
@@ -155,7 +160,94 @@ void singinggame_duetto_clicked(TangleAction *action, GObject *source, const gch
 	tangle_button_set_normal_background_actor(TANGLE_BUTTON(button), texture);
 }
 	
+	gboolean first_time_in_songselection = TRUE;
+
+static void entering_first_time_to_songselection(TangleAction* action, GObject* source, const gchar* trigger, TangleProperties* properties) {
+	if (first_time_in_songselection){
+		ClutterActor* new_parent =  jammo_get_actor_by_id("songselection-view");
+		if (new_parent==NULL) printf("new_parent is NULL\n");
+		else printf("new_parent not NULL\n");
+		
+		ClutterActor *temp_bear=mentor_give_temp_bear();
+		clutter_container_add_actor (CLUTTER_CONTAINER (new_parent), temp_bear);
+
+		mentor_speech(temp_bear,"mentor_speech/mentor_06_fi.ogg");
 	
+	first_time_in_songselection = FALSE;
+	}
+}
+
+	
+ClutterColor white_color = { 0, 0, 0, 0xbb };
+ClutterColor *get_white_color(){        return &white_color; }
+
+void jammo_going_to_songselection(TangleAction *action, GObject *source, const gchar *trigger, TangleProperties *properties){
+		ClutterActor* view;
+		if ((view = jammo_get_actor_by_id("songselection-view"))) {
+			g_object_set(view, "transition-duration", 1500, "transition-mode", 2, NULL);
+			clutter_actor_show(view);
+		}
+	if (first_time_in_songselection)
+		{
+		//Mentor's speech.
+		g_signal_connect(view, "transition-completed", G_CALLBACK(entering_first_time_to_songselection), NULL);
+		}
+
+
+	//Add transperency mask to songs which do not have current language vocal-track.
+	///////////////////////////////////////////////////////////////////////////////
+	char* selected_language = chum_get_selected_language();
+	gfloat x,y,w,h;
+	ClutterActor* box;
+	GList* songlist = clutter_container_get_children(CLUTTER_CONTAINER(view));
+	GList *l;
+
+	//First: Remove all existing mask-boxes. FIXME: now it only hides them!
+	for (l = songlist; l; l = l->next){
+		const gchar* name;
+		g_object_get(l->data, "name", &name, NULL);
+		if (name!=NULL && strncmp(name,"box",3)==0)
+			{
+			//clutter_actor_hide(l->data);
+			//clutter_container_remove_actor(CLUTTER_CONTAINER(view), CLUTTER_ACTOR(l->data));
+			clutter_container_remove_actor(CLUTTER_CONTAINER(view), CLUTTER_ACTOR(l->data));
+			}
+	}
+	g_list_free(songlist);
+
+	//Second: add new boxes
+	songlist = clutter_container_get_children(CLUTTER_CONTAINER(view));
+	for (l = songlist; l; l = l->next){
+		const gchar* id_of_actor;
+		id_of_actor = clutter_get_script_id(G_OBJECT(l->data));
+		if (id_of_actor==NULL) continue; //In child-list there are many id=NULL actors.
+			
+		if (strncmp(id_of_actor,"songselection-song-",19)==0)
+			{
+			const gchar* name;
+			g_object_get(l->data, "name", &name, NULL);
+		  //printf("name: '%s'\n",name);
+			
+			gchar* filename;
+			filename = g_strdup_printf("%s/songs/%s/vocal%s.ogg",DATA_DIR,name,selected_language);
+			//printf("filename: '%s'\n",filename);
+			int fd = open(filename,O_RDONLY);
+			if (fd == -1) //File not found => now vocal_track for this language
+				{
+				g_object_get(l->data, "x", &x, "y", &y, "width", &w, "height", &h, NULL);
+				//printf("child: %s, %lf: %lf: %lf: %lf\n",id_of_actor,x,y,w,h);
+				box=clutter_rectangle_new_with_color (get_white_color());
+				clutter_actor_set_size (box, w,h);
+				clutter_actor_set_position (box, x, y); 
+				clutter_actor_show (box);
+				clutter_actor_set_name (box, "box"); //this is used to remove this b
+				clutter_container_add_actor (CLUTTER_CONTAINER (view), box);
+				}
+			}
+	}
+	
+	g_list_free(songlist);
+}
 
 void singinggame_language_clicked(TangleAction *action, GObject *source, const gchar *trigger, TangleProperties *properties){
 	ClutterActor* ct =CLUTTER_ACTOR(source);
@@ -163,46 +255,48 @@ void singinggame_language_clicked(TangleAction *action, GObject *source, const g
 	printf("Lan clicked. get_name: '%s'\n",name);
 
 	chum_set_selected_language(name);
-	ClutterActor* new_actor =tangle_button_get_normal_background_actor(ct);
-	/*gchar* filename;
-	g_object_get(G_OBJECT(new_actor), "filename", &filename, NULL);
-	//filename is not readable
-*/
-	
 
 	ClutterActor* button;
 	ClutterActor* texture;
 	gchar *new_name = g_strdup_printf("songselection-language-%s-texture", name);
-	 
+ 
 	button = jammo_get_actor_by_id("songselection-language");
 	texture = jammo_get_actor_by_id(new_name);
 	tangle_button_set_normal_background_actor(TANGLE_BUTTON(button), texture);
+
+
+	ClutterActor* view;
+	if ((view = jammo_get_actor_by_id("language-selection-view"))) {
+		g_object_set(view, "transition-duration", 1500, "transition-mode", 2, NULL);
+		clutter_actor_hide(view);
+	}
+
+	jammo_going_to_songselection(action,source,trigger,properties);
 }
 
 
-extern gboolean use_main_menu_mentor;
-gboolean first_time_in_songselection = TRUE;
 
-static void on_transition_completed2(TangleAction* action, GObject* source, const gchar* trigger, TangleProperties* properties) {
-	if (first_time_in_songselection){
-				use_main_menu_mentor=FALSE;
-		mentor_speech("mentor_speech/mentor_06_fi.ogg");
-	
-	first_time_in_songselection = FALSE;
+
+
+
+
+gboolean first_time_ask_quitting = TRUE;
+void jammo_ask_quitting2(){
+	if (first_time_ask_quitting){
+		ClutterActor* new_parent;
+		new_parent = jammo_get_actor_by_id("quitconfirmation-view");
+		ClutterActor *temp_bear=mentor_give_temp_bear();
+		clutter_container_add_actor (CLUTTER_CONTAINER (new_parent), temp_bear);
+		mentor_speech(temp_bear,"mentor_speech/mentor_quit_confirmation_fi.ogg");
+		first_time_ask_quitting=FALSE;
 	}
-}
-
-
-void jammo_going_to_songselection(TangleAction *action, GObject *source, const gchar *trigger, TangleProperties *properties){
-		ClutterActor* actor;
-		if ((actor = jammo_get_actor_by_id("songselection-view"))) {
-		g_object_set(actor, "transition-duration", 1500, "transition-mode", 2, NULL);
-		clutter_actor_show(actor);
-	}
-	if (first_time_in_songselection)
-		{
-		g_signal_connect(actor, "transition-completed", G_CALLBACK(on_transition_completed2), NULL);
-		}
 	
 }
 
+void jammo_ask_quitting(TangleAction *action, GObject *source, const gchar *trigger, TangleProperties *properties){
+	ClutterActor* new_parent;
+	new_parent = jammo_get_actor_by_id("quitconfirmation-view");
+
+	g_signal_connect(new_parent, "transition-completed", G_CALLBACK(jammo_ask_quitting2), NULL);	
+}
+
