@@ -43,6 +43,7 @@ typedef enum {
 } JammoInstrumentType;
 JammoInstrumentTrack* jammo_instrument_track_new(JammoInstrumentType instrument_type);
 
-void jammo_instrument_track_set_note(JammoInstrumentTrack* instrument_track,char note, int octave);
+void jammo_instrument_track_set_and_play_note_realtime(JammoInstrumentTrack* instrument_track, char note, int octave);
+void jammo_instrument_track_set_realtime(JammoInstrumentTrack* instrument_track, gboolean state);
 
 #endif
